#!/usr/bin/perl -w 
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

package Vhffs::Conf;

use strict;
use Config::General;

#Vhffs::Conf written by sod` <dieu AT gunnm DOT org>

#This is obviously a good way to manage the configuration of Vhffs
#Config::General helps a bit, for sure


my %Config;
my $filename;

sub new
{
    my $class;
    my $self;


    my ( $this , $param ) = @_;
    $class = ref($this) || $this;

    $self={
	filename => $param,
    };

    $filename = $param;

    bless($self , $class );

    return $self;
}



#Parse the main Vhffs Configuration file
sub parse
{
    my $conf;
    
    $conf = new Config::General( 
				 -ConfigFile => $filename ,
				 );
    %Config = $conf->getall();

	$Config{'users'}{'default_city'} = "City" if ( !defined $Config{'users'}{'default_city'} );
	$Config{'users'}{'default_country'} = "Country" if ( !defined $Config{'users'}{'default_country'} );
	$Config{'users'}{'default_lastname'} = "Lastname" if ( !defined $Config{'users'}{'default_lastname'} );
	$Config{'users'}{'default_firstname'} = "Firstname" if ( !defined $Config{'users'}{'default_firstname'} );
	$Config{'users'}{'default_mail'} = "user\@domain.ex" if ( !defined $Config{'users'}{'default_mail'} );
	$Config{'users'}{'default_zipcode'} = "121231" if ( !defined $Config{'users'}{'default_zipcode'} );
	$Config{'users'}{'default_address'} = "1 in the street" if ( !defined $Config{'users'}{'default_address'} );

	$Config{'users'}{'shell'} = "/bin/false" if( ! defined $Config{'users'}{'shell'} );

    return \%Config;
}

#return a reference to a hash with the configuration of the backend
sub get_backend
{
    return $Config{"backend"};
}


sub get_databases
{
    return $Config{"databases"};
}




#return the host configuration
sub get_host
{
    return $Config{"host"};
}


# get a service configuration
# if a parameter is given, the configuration of the service will be returned
# if not, it returns the whole configuration for all services
sub get_service
{
    my $service;
    my $self;
    ($self , $service ) = @_;

    return $Config{"services"}{$service} if( defined $service ) ;

    return $Config{"services"};    
}

sub get_default_apache_domain
{
	my $self = shift;
	if( defined $Config{"services"}{"apache"}{"default_domain"} )
	{
		return $Config{"services"}{"apache"}{"default_domain"};
	}
	else
	{
		return undef;
	}
}

sub get_default_a
{
	my $self = shift;
    if( defined $Config{"services"}{"dns"}{"default_a"} )
    {
        return $Config{"services"}{"dns"}{"default_a"};
    }
    else
    {
        return undef;
    }

}

sub get_users
{
    return $Config{"users"};    
}


#Open the file of bad username, fill a table with them and return a reference to it
sub get_bad_username
{
    my $badusers;

    if( ( defined $Config{"users"}{"bad_username_file"} ) && ( -f $Config{"users"}{"bad_username_file"} ) )
    {
	    open MYFILE , $Config{"users"}{"bad_username_file"};
	
	    while( <MYFILE> )
	    {
	        chomp;
	        push( @{$badusers} , $_ );
	    } 

	    close MYFILE;
	    return $badusers;
    }
    else
    {
	    return undef;
    }
    
}


#Same thing than get_bad_username, but for group
sub get_bad_groupname
{
    my $badgroups;

    if( ( defined $Config{"users"}{"bad_groupname_file"} ) && ( -f $Config{"users"}{"bad_groupname_file"} ) )
    {
	    open MYFILE , $Config{"users"}{"bad_groupname_file"};
	
	    while( <MYFILE> )
	    {
	        chomp;
	        push( @{$badgroups} , $_ );
	    } 

	    close MYFILE;
	    return $badgroups;
    }
    else
    {
	    return undef;
    }
    
}


sub use_web
{
	return -1 if( ! defined $Config{"global"}{"modules"}{'use_web'} );
	return 1 if( $Config{"global"}{"modules"}{'use_web'} eq "yes" );
	return 0;
}


sub use_cvs
{
	return -1 if( ! defined $Config{"global"}{"modules"}{'use_cvs'} );
	return 1 if( $Config{"global"}{"modules"}{'use_cvs'} eq "yes");
	return 0;
}


sub use_svn
{
	return -1 if( ! defined $Config{"global"}{"modules"}{'use_svn'} );
	return 1 if( $Config{"global"}{"modules"}{'use_svn'} eq "yes");
	return 0;
}


sub use_largefile
{
	return -1 if( ! defined $Config{"global"}{"modules"}{'use_largefile'} );
	return 1 if( $Config{"global"}{"modules"}{'use_largefile'} eq "yes");
	return 0;
}


sub use_repository
{
	return -1 if( ! defined $Config{"global"}{"modules"}{'use_repository'} );
	return 1 if( $Config{"global"}{"modules"}{'use_repository'} eq "yes");
	return 0;
}

sub use_mail
{
	return -1 if( ! defined $Config{"global"}{"modules"}{'use_mail'} );
	return 1 if( $Config{"global"}{"modules"}{'use_mail'} eq "yes");
	return 0;
}



sub use_mailuser
{
	return -1 if( ! defined $Config{"global"}{"modules"}{'use_mailuser'} );
	return 1 if( $Config{"global"}{"modules"}{'use_mailuser'} eq "yes");
	return 0;
}



sub use_mailling
{
	return -1 if( ! defined $Config{"global"}{"modules"}{'use_mailling'} );
	return 1 if( $Config{"global"}{"modules"}{'use_mailling'} eq "yes");
	return 0;
}

sub use_mailing
{
	return -1 if( ! defined $Config{"global"}{"modules"}{'use_mailing'} );
	return 1 if( $Config{"global"}{"modules"}{'use_mailing'} eq "yes");
	return 0;
}


sub use_dns
{
	return -1 if( ! defined $Config{"global"}{"modules"}{'use_dns'} );
	return 1 if( $Config{"global"}{"modules"}{'use_dns'} eq "yes");
	return 0;
}





sub use_postgres
{
	return -1 if( ! defined $Config{"global"}{"modules"}{'use_postgres'} );
	return 1 if( $Config{"global"}{"modules"}{"use_postgres"} eq "yes");
	return 0;
}




sub use_mysql
{
	return -1 if( ! defined $Config{"global"}{"modules"}{'use_mysql'} );
	return 1 if( $Config{"global"}{"modules"}{'use_mysql'} eq "yes");
	return 0;
}




sub get_allow_subscribe
{
	return -1 if( ! defined $Config{"global"}{"allow_subscribe"} );
	return 1 if( ( $Config{"global"}{"allow_subscribe"} eq "yes")  );
	return 0;
}


sub get_alert_mail
{
	if( defined $Config{"global"}{"alert_mail"} )
	{
		return $Config{"global"}{"alert_mail"};
	}
	else
	{
		return "nobody\@nobody.com";
	}
}





sub get_datadir
{
	return $Config{"global"}{"datadir"};
}

sub get_templatedir
{
    return $Config{"global"}{"templatedir"};
}


sub get_templatesdir
{
    return $Config{"global"}{"templatedir"};
}


sub get_default_theme
{
        return $Config{"global"}{"default_theme"};
}


sub get_intldir
{
    return $Config{"global"}{"intldir"};
}


sub get_default_language
{
        return $Config{"global"}{"default_language"};
}


sub get_mailtag
{

	if( defined $Config{"global"}{"mailtag"} )
	{
    	return $Config{"global"}{"mailtag"};
	}
	else
	{
		return undef;
	}
}


sub get_master_mail
{

	if( defined $Config{"global"}{"vhffs_master"} )
	{
    	return $Config{"global"}{"vhffs_master"};
	}
	else
	{
		return undef;
	}
}


sub get_moderator_mail
{

	if( defined $Config{"global"}{"vhffs_moderator"} )
	{
    	return $Config{"global"}{"vhffs_moderator"};
	}
	else
	{
		return undef;
	}
}



sub get_mysql_admin_pass
{
	return $Config{"services"}{"mysql"}{"password"};
}

sub get_mysql_admin_host
{
	return $Config{"services"}{"mysql"}{"host"};
}

sub get_mysql_admin_username
{
	return $Config{"services"}{"mysql"}{"username"};
}


sub get_pgsql_admin_pass
{
	return $Config{"services"}{"postgresql"}{"password"};
}

sub get_pgsql_admin_host
{
	return $Config{"services"}{"postgresql"}{"host"};
}

sub get_pgsql_admin_username
{
	return $Config{"services"}{"postgresql"}{"username"};
}


sub get_svn_repodir
{
	if( defined $Config{"services"}{"subversion"}{"repo_dir"} )
	{
		return $Config{"services"}{"subversion"}{"repo_dir"};
	}
	else
	{
		return "/data/svn/svnroot";
	}
}


sub get_svn_helpurl
{
	if( defined $Config{"services"}{"subversion"}{"help_url"} )
	{
		return $Config{"services"}{"subversion"}{"help_url"};
	}
	else
	{
		return "/svn/help.html";
	}
}




sub get_svn_gid
{
	if( defined $Config{"services"}{"subversion"}{"gid"} )
	{
		return $Config{"services"}{"subversion"}{"gid"};
	}
	else
	{
		return "0";
	}
}


sub get_svn_uid
{
	if( defined $Config{"services"}{"subversion"}{"uid"} )
	{
		return $Config{"services"}{"subversion"}{"uid"};
	}
	else
	{
		return "0";
	}
}


sub get_svn_configdir
{
	if( defined $Config{"services"}{"subversion"}{"config_dir"} )
	{
		return $Config{"services"}{"subversion"}{"config_dir"};
	}
	else
	{
		return "/data/svn/conf";
	}
}

sub get_themesdir
{
	if( defined $Config{"global"}{"themesdir"} )
	{
		return $Config{"global"}{"themesdir"};
	}
	else
	{
		return undef;
	}
}

sub get_panel_public
{
	if( $Config{"global"}{"panel"}{use_public} )
	{
		if( $Config{"global"}{"panel"}{use_public} eq "yes" )
		{
			return 1;
		}
	}
	return 0;
}

sub get_panel_open
{
	if( $Config{"global"}{"panel"}{"open"} )
	{
		if( $Config{"global"}{"panel"}{"open"} eq "yes" )
		{
			return 1;
		}
	}
	return 0;
}

sub get_panel_avatar
{
	if( $Config{"global"}{"panel"}{"use_avatar"} )
	{
		if( $Config{"global"}{"panel"}{'use_avatar'} eq "yes" )
		{
			return 1;
		}
	}
	return 0;
}



sub use_notation
{
	if( $Config{"global"}{"panel"}{use_notation} )
	{
		if( $Config{"global"}{"panel"}{use_notation} eq "yes" )
		{
			return 1;
		}
	}
	return 0;
}



sub get_panel_public_users
{
    if( $Config{"global"}{"panel"}{users} )
    {
        if( $Config{"global"}{"panel"}{users} eq "yes" )
        {
            return 1;
        }
    }
    return 0;
}


sub get_panel_public_groups
{
    if( $Config{"global"}{"panel"}{groups} )
    {
        if( $Config{"global"}{"panel"}{groups} eq "yes" )
        {
            return 1;
        }
    }
    return 0;
}

sub get_panel_rss_users
{
    if( $Config{"global"}{"panel"}{rss}{users} )
    {
        if( $Config{"global"}{"panel"}{rss}{users} eq "yes" )
        {
            return 1;
        }
    }
    return 0;
}


sub get_panel_rss_groups
{
    if( $Config{"global"}{"panel"}{rss}{groups} )
    {
        if( $Config{"global"}{"panel"}{rss}{groups} eq "yes" )
        {
            return 1;
        }
    }
    return 0;
}



sub get_panel_url
{
	if( $Config{"global"}{"panel"}{url} )
	{
		return $Config{"global"}{"panel"}{url};	
	}
	else
	{
		return undef;
	}
}


sub get_panel_phppgadminurl
{
	if( $Config{"global"}{"panel"}{phppgadmin_url} )
	{
		return $Config{"global"}{"panel"}{phppgadmin_url};	
	}
	else
	{
		return undef;
	}
}


sub get_panel_statsurl
{
	if( $Config{"global"}{"panel"}{stats_url} )
	{
		return $Config{"global"}{"panel"}{stats_url};	
	}
	else
	{
		return undef;
	}
}


sub get_panel_helpurl
{
	if( $Config{"global"}{"panel"}{help_url} )
	{
		return $Config{"global"}{"panel"}{help_url};	
	}
	else
	{
		return undef;
	}
}


sub get_panel_phpmyadminurl
{
	if( $Config{"global"}{"panel"}{phpmyadmin_url} )
	{
		return $Config{"global"}{"panel"}{phpmyadmin_url};	
	}
	else
	{
		return undef;
	}
}

sub stats_on_home
{
    if( defined $Config{"global"}{"panel"}{"stats_on_home"} )
    {
	if( $Config{"global"}{"panel"}{"stats_on_home"} eq "yes" )
	{
	    return 1;
	}
	
    }
    return 0;
}

sub get_host_name
{
   if( defined $Config{"global"}{host_name} )
    {
	return $Config{"global"}{host_name};
    }
   else
   {
       return "host";
   }
}


sub get_listengine_domain
{
	if( defined $Config{"services"}{"listengine"}{"domain"} )
	{
		return $Config{"services"}{"listengine"}{"domain"};
	}
	else
	{
		return "host.tld";
	}
}

sub get_listengine_listmaster
{
	if( defined $Config{"services"}{"listengine"}{"listmaster"} )
	{
		return $Config{"services"}{"listengine"}{"listmaster"};
	}
	else
	{
		return "listmaster\@unknownhost.tld";
	}
}


sub get_listengine_datadir
{
	if( defined $Config{"services"}{"listengine"}{"datadir"} )
	{
		return $Config{"services"}{"listengine"}{"datadir"};
	}
	else
	{
		return $Config{"global"}{datadir}."/listengine/";
	}
}



sub get_listengine_smtp
{
	if( defined $Config{"services"}{"listengine"}{"smtp_server"} )
	{
		return $Config{"services"}{"listengine"}{"smtp_server"};
	}
	else
	{
		return "localhost";
	}
}

sub get_listengine_templatesdir
{
	if( defined $Config{"services"}{"listengine"}{"templatesdir"} )
	{
	    return $Config{"services"}{"listengine"}{"templatesdir"};
	}
	else
	{
	    return undef;
	}
}


sub get_cvsdocurl
{
	if( defined $Config{"services"}{"cvs"}{"cvsdoc_url"} )
	{
	    return $Config{"services"}{"cvs"}{"cvsdoc_url"};
	}
	else
	{
	    return "http://doc";
	}
}


sub get_cvsweburl
{
	if( defined $Config{"services"}{"cvs"}{"cvsweb_url"} )
	{
	    return $Config{"services"}{"cvs"}{"cvsweb_url"};
	}
	else
	{
	    return "cvsweb";
	}
}


sub get_svnweburl
{
	if( defined $Config{"services"}{"subversion"}{"svnweb_url"} )
	{
	    return $Config{"services"}{"subversion"}{"svnweb_url"};
	}
	else
	{
	    return "svnweb";
	}
}


sub get_repositoryurl
{
	if( defined $Config{"services"}{"repository"}{"repository_url"} )
	{
	    return $Config{"services"}{"repository"}{"repository_url"};
	}
	else
	{
	    return "repository";
	}
}

sub use_nospam
{
	return -1 if( ! defined $Config{"services"}{"mail"} );
	return -1 if( ! defined $Config{"services"}{"mail"}{'use_nospam'} );
	return 1 if( $Config{"services"}{"mail"}{'use_nospam'} eq "yes");
	return 0;
}

sub use_novirus
{
	return -1 if( ! defined $Config{"services"}{"mail"} );
	return -1 if( ! defined $Config{"services"}{"mail"}{'use_novirus'} );
	return 1 if( $Config{"services"}{"mail"}{'use_novirus'} eq "yes");
	return 0;
}


sub robots_logging
{
	if( $Config{"robots"}{"use_logging"} )
	{
		if( $Config{"robots"}{"use_logging"} eq "yes" )
		{
			return 1;
		}
	}
	return 0;
}

sub robots_logfile
{
	if( defined $Config{"robots"}{"logfile"} )
	{
		return( $Config{"robots"}{"logfile"} );
	}
	return undef;
}

sub use_locking
{
	if( $Config{"robots"}{"use_lock"} )
	{
		if( $Config{"robots"}{"use_lock"} eq "yes" )
		{
			return 1;
		}
	}
	return 0;
}

sub robot_lockfile
{
	if( defined $Config{"robots"}{"lockfile"} )
	{
		return( $Config{"robots"}{"lockfile"} );
	}
	return undef;
}

sub largefile_mirrors
{
	if( defined $Config{"services"}{"largefile"}{"mirrors"}{"server"} )
	{
		return( $Config{"services"}{"largefile"}{"mirrors"}{"server"} );
	}
}

sub largefile_upload_host
{
	if( defined $Config{"services"}{"largefile"}{"upload-host"} )
	{
		return( $Config{"services"}{"largefile"}{"upload-host"} );
	}
}

sub get_www_archives
{
	if( defined $Config{"services"}{"listengine"}{"www-archives"} )
	{
		return( $Config{"services"}{"listengine"}{"www-archives"} );
	}
}


sub get_moderation
{
	if( ( defined $Config{"global"}{"moderation"} ) && ( $Config{"global"}{"moderation"} eq 'yes' ) )
	{
		return( 1 );
	}
	return( 0 );
}

sub get_web_config
{
	return $Config{"services"}{"web"};
}

sub get_repository_config
{
	return $Config{"services"}{"repository"};
}

1;
