#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.




package Vhffs::Object;

use Vhffs::Constants;

sub new
{
    my $main;
    my $owner;
    my $id;
    my $this;
    my $self;
    my $class;
    
    
    ( $this , $main , $id , $owner ) = @_;
    
    $self={};

    $class = ref($this) || $this;
    bless($self , $class );
   
    return undef if ( ! defined $main );
    return undef if ( ( ! defined $id ) || ( ! defined $owner ) ); 
    
    $self->{'main'} = $main;
    $self->{'db'} = $main->get_db_object;
    $self->{'owner_uid'} = $owner;
    $self->{'description'} = "";
    
    
    if ( defined $id )
    {
        $self->{'object_id'} = $id;
    }
    else
    {
        $self->{'object_id'} = 0;
    }
   
    return $self;
}

sub get_main
{
    my $self = shift;
    
    if( defined $self->{'main'} )
    {
	return $self->{'main'};
    }
    else
    {
	return undef;
    }
}


sub delete
{
    my $self = shift;

	my $query;
	my $request;


	#First, delete all Notes pointing on this object
    $query = "DELETE FROM vhffs_notes WHERE object_id='".$self->{'object_id'}."'";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare($query);
    $request->execute or return -2;

	#Then, delete all ACL referes to this object
    $query = "DELETE FROM vhffs_acl WHERE oid_dst='".$self->{'object_id'}."'";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare($query);
    $request->execute or return -2;
   
   	#Delete all ACL from this object
	$query = "DELETE FROM vhffs_acl WHERE oid_src='".$self->{'object_id'}."'";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare($query);
    $request->execute or return -2;

	#Delete history from this object
    $query = "DELETE FROM vhffs_history WHERE object_id='".$self->{'object_id'}."'";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare($query);
    $request->execute or return -1;

    $query = "DELETE FROM vhffs_object WHERE object_id='".$self->{'object_id'}."'";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare($query);
    $request->execute or return -1;

    return 1;
}

sub toString
{
    my ($self) = @_;

    foreach ( keys %$self )
    {
        print "$_: $self->{$_} ";
    }
}

sub create
{
    my $query;
    my $request;
    my $id;
    my ( $self ) = @_;


	$self->{'owner_uid'} = $user->get_uid if( defined $user );
	$self->{'owner_gid'} = $group->get_gid if( defined $group );

	$self->set_default_state;

    $id = 0;
    $request = $self->{'db'}->{'DB_READ'}->selectall_arrayref("SELECT MAX(object_id) FROM vhffs_object") or return -2;
    $id = $request->[0][0] if( defined $request->[0][0] );
    $id++;
    $self->{'object_id'} = $id;
	$request = $self->{'db'}->{'DB_WRITE'}->prepare("INSERT INTO vhffs_object VALUES ( ? , ? , NOW(), ? , ? )");

    $request->execute( $self->{'object_id'} , $self->{'owner_uid'} , $self->{'state'} , $self->{'description'} )  or return -2;

	$self->add_history( "Object created" );

    return $self->{'object_id'};
}



sub fetch
{
    my $self;
    my $request;
    my $result;

    $self = shift;
   
	my $query = "SELECT * FROM vhffs_object WHERE object_id ='". $self->{'object_id'}."'" ;
    $request = $self->{'db'}->{'DB_READ'}->prepare( $query );
    my $rows = $request->execute;
    
    return -1 if( $rows != 1);

    $result = $request->fetchrow_hashref;

    foreach ( keys %{$result} )
    {
		$self->{"$_"} = $result->{"$_"}
    }

	#Fix encofing of description
	$self->{'description'} =~ s/\\//g;


    return 1;    
}

sub fetch_object
{
	my $self = shift;
	$self->fetch();
}

sub get_owner_uid
{
	my $self = shift;
	return $self->{'owner_uid'};
}


#The modify method for Vhffs::Object only tells if the API can modify some values
#It protects some importants fields such as object_id
sub modify
{
    my $self;
    my $field;
    my $value;

    ($self , $field , $value ) =  @_;

    return -1 if( $field eq "object_id" );

    return 0;
}


sub commit
{
    my $self = shift;
    my $request;

	$self->{description} = quotemeta $self->{description};

    $request = "UPDATE vhffs_object SET state=?, description=?, owner_uid=? WHERE object_id=?";
    my $result = $self->{'db'}->{'DB_WRITE'}->prepare($request);
    $result->execute( $self->{'state'} , $self->{'description'} , $self->{'owner_uid'} , $self->{'object_id'} );;

}

sub get_date
{
	my $self = shift;
	if( defined $self->{'date_creation'} )
	{
		return $self->{'date_creation'};
	}
	else
	{
		return undef;
	}
}

sub get_oid
{
    my $self = shift;
    return $self->{'object_id'};
}

sub get_description
{
    my $self = shift;
    return $self->{'description'};
}

sub set_owner
{
   my ( $self , $value ) = @_;
   $self->{'owner_uid'} = $value;
}


sub get_status
{
	my $self = shift;
	return $self->{'state'};
}

sub set_status
{
	my ($self , $value);
	$self = shift;
	$value = shift;
	$self->{'state'} = $value;
	
	if( $value == Vhffs::Constants::TO_DELETE )
	{
		$self->add_history( "Will be delete" );
	}
	elsif( $value == Vhffs::Constants::WAITING_FOR_CREATION )
	{
		$self->add_history( "Moderated. Will be created" );
	}
	elsif( $value == Vhffs::Constants::CREATING_ERROR )
	{
		$self->add_history( "Creating error ! Robots can't create it." );
	}
	elsif( $value == Vhffs::Constants::CREATED )
	{
		$self->add_history( "Object is created." );
	}
	elsif( $value == Vhffs::Constants::WAITING_FOR_VALIDATION )
	{
		$self->add_history( "Object is under moderation.");
	}
	elsif( $value == Vhffs::Constants::VALIDATION_REFUSED )
	{
		$self->add_history( "Validation refused.");
	}
	elsif( $value == Vhffs::Constants::ACTIVATED )
	{
		$self->add_history( "Is now active for production.");
	}
	
	
}


sub set_default_state
{
use Vhffs::Debug;
	my $self = shift;
	my $vhffs = $self->{'main'};

	if( $vhffs->get_config->get_moderation == 1 )
	{
		$self->set_status( Vhffs::Constants::WAITING_FOR_VALIDATION );
	}
	else
	{
		$self->set_status( Vhffs::Constants::WAITING_FOR_CREATION );
	}
	return( 1 );
}

sub set_description
{
	my ($self , $value) = @_;
	$value =~ s/\?/ \?/g;
	$self->{'description'} = quotemeta( $value );
}


sub set_to_delete
{
	my($self , $value ) = @_;
	$self->{'state'} = "D";
}

sub add_history
{
	my $self = shift;
	my $message = shift;
	$message = quotemeta( $message );

	my $id = 0;
	my $query = "SELECT MAX(history_id) FROM vhffs_history";
	my $request = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query ) or return -2;
	$id = $request->[0][0] if( defined $request->[0][0] );
	$id++;

	$query = "INSERT INTO vhffs_history VALUES('".$id."','".$self->{'object_id'}."',NOW(),'".$message."')";
	$request = $self->{'db'}->{'DB_WRITE'}->prepare( $query );
	$request->execute or return -2;

	return $id;
}

# Returns a hashref wich contains all the history
sub get_history
{
	use Vhffs::Functions;
	my $self = shift;

	my $result;
	my $key;
	my $value;

	my $query = "SELECT * FROM vhffs_history WHERE object_id='".$self->{'object_id'}."'";
	my $request = $self->{'db'}->{'DB_READ'}->prepare( $query );

	return undef if( $request->execute <= 0 );

	$temp = $request->fetchall_hashref('history_id');
	foreach $key ( keys ( %{$temp} ))
	{
		$temp->{$key}{'message'} = Vhffs::Functions::stripslashes( $temp->{$key}{'message'} );
	}
	return $temp;
}


#Get all objects of the database.
#If $name is undefined, the functions returns ALL objects.
#Else, it returns objects like the name. It searchs in oid, user and description
#The first arg is a valid instance of Vhffs::Main
sub getall
{
	my $vhffs = shift;
	my $name = shift;

	my $query;

	if( defined $name )
	{
		$query = "SELECT o.object_id, o.owner_uid, o.date_creation , o.state , o.description FROM vhffs_object o, vhffs_users u WHERE o.owner_uid=u.uid AND ( ( o.description LIKE '%".$name."%' ) OR ( o.object_id LIKE '%".$name."%' ) OR ( o.owner_uid LIKE '%".$name."%') OR ( state LIKE '%".$name."%' ) OR (u.username LIKE '%".$name."%') )";
	}
	else
	{
		$query = "SELECT o.object_id, o.owner_uid, o.date_creation , o.state , o.description FROM vhffs_object o";
	}
	my $request = $vhffs->get_db_object->{'DB_READ'}->prepare( $query ) or return -1;

	return undef if ( $request->execute() <= 0);
	
	return( $request->fetchall_hashref('object_id') );
}

sub get_group
{
    my $self = shift;
    if( defined $self->{'group'} )
	{
		return( $self->{'group'} );
	}
	else
	{
		if( defined $self->{'owner_gid'} )
		{
			use Vhffs::Group;
			$self->{'group'} = new Vhffs::Group( $self->{'main'} , undef ,  $self->{'owner_uid'} , $self->{'owner_gid'} );
			return( $self->{'group'} ) if( defined( $self->{'group'} ) && (  $self->{'group'}->fetch > 0 ) );
		}
	}
    return undef;
}


sub get_user
{
    my $self = shift;
    if( defined $self->{'user'} )
	{
		return( $self->{'user'} );
	}
	else
	{
		if( defined $self->{'owner_uid'} )
		{
			use Vhffs::User;
			$self->{'user'} = new  Vhffs::User( $self->{'main'} , undef , $self->{'owner_uid'} );
			return( $self->{'user'} ) if( defined ( $self->{'user'} ) && (  $self->{'user'}->fetch > 0 ));
		}
	}
    return undef;
}



1;
			    
__END__

=head1 SYNOPSIS

Vhffs::Object - The generic object type in VHFFS

=head1 DESCRIPTION

The Vhffs::Object type is the base of each Vhffs::Services::*, Vhffs::User
or Vhffs::Group objects. So, you never have to create an instance of Vhffs::Object
, this class is only use as a super-class for services (or user or group).

So, the method of Vhffs::Object can be applied to all class which inherit of it.
Commonly, you can have all the history of an object with a method, get the status
of a service, ...

This type stored informations about state, history, owner group/user.

=head1 METHODS

=head2 new( Vhffs::Main , 1 , '401')

Create an instance of Vhffs::Object. Typically, this method is onvoked is the new method of inherited class. It creates an object, with a fixed object-id (arg 2) and the owner from uid (arg3).
The first argument is a Vhffs::Main object.
Return undef if failed.

=head2 get_main( )

This method returns the Vhffs::Main object contained in this object.
This method can be useful if you have an object and you need a Vhffs::Main instance.

=head2 delete( )

Delete the object. This method is called from inherited class.
Note that it destroy the object-part (history, ...), but not the inherited class.
Returns negative value if fails, positive if success.

=head2 commit( )

Apply all changes that were made on this object. Returns negative value if failed, positive if success.

=head2 fetch( )

Get informations for this object from the database. Typically, you create an instance of Vhffs::Object with a valid object-id and when you call fetch, it takes all informations about this object in the database according to the object-id.

=head2 fetch_object( )
Same as fetch()

=head2 get_owner_uid( )

Returns the uid that own this Object.

=head2 modify( $field , $value )

Modify a propertiy of this object. For example, modify( "description" , "my_description") will change the description of this Object. If you want update those modified informations on the database, you need to call commit() to update informations in the database. Note that you never had to change object-id of an object.

=head2 get_date( )

Returns the date of the creation for this object.

=head2 get_oid( )

Returns the object_id of this Object.

=head2 get_description( )

Returns the description of this object.

=head2 set_owner( )

Change the uid of the owner of this object.

=head2 get_status( )

Get the status of this object. The status are given in the Vhffs::Constants class.

=head2 set_status( )

Change the status of an object. The status are available as constants in Vhffs::Constants class. When you change the status of an object, a message is added in its history.

=head2 set_description( $string )

Change the description of an object. As all accessors, you need to call commit() method after.

=head2 add_history( $string )

Add a message in the object's history.

=head2 get_history( )

Returns an hashref that represent the history of this object. This object has as key the date of each history message. For exemple :

$history = $object->get_history();

if( defined $history )

{

	foreach $key ( keys %{$history} )

	{

		print "At date " . $key . " message: " . $history->{$key}{'message'};

	}

}

=head2 get_group( )

Returns the Vhffs::Group instance that own this object. Returns undef is fails.

=head2 get_user( )

Returns the Vhffs::User instance that own this object. Returns undef is fails.

=head2 getall( Vhffs::Main , $name )

The getall is very important and defined in every service. In Vhffs::Object,
it returns all object if $name is not defined (undef). Return all objects that matches with $name if $name is defined.

=head1 SEE ALSO
Vhffs::Constants Vhffs::User Vhffs::Group

=head1 AUTHOR

	Julien Delange <julien at gunnm dot org>

=head1 COPYRIGHT

	Julien Delange <julien at gunnm dot org>
