#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


package Vhffs::Robots::Mysql;

require 5.004;
# use strict;
use POSIX;
use locale;
use Locale::gettext;
use Vhffs::Services::Mysql;
use Vhffs::Constants;
use Vhffs::Functions;

setlocale(LC_ALL, "en_US");
bindtextdomain("panel", "/vhffs/vhffs-panel/intl");
textdomain("panel");


sub getall_refused
{
	my( $main ) = @_;
	
	my $query = "SELECT m.dbname, m.object_id FROM  vhffs_mysql m, vhffs_object o WHERE o.state='".Vhffs::Constants::VALIDATION_REFUSED."' AND m.object_id = o.object_id";

	$request = $main->{'db'}->{'DB_READ'}->prepare( $query ) or return -2;
	return undef if ( $request->execute() <= 0 );

	return( $request->fetchall_hashref('dbname') );
}


sub get_all_db_to_create
{
	my( $main ) = @_;
	
	my $query = "SELECT m.dbname, m.object_id FROM  vhffs_mysql m, vhffs_object o WHERE o.state='".Vhffs::Constants::WAITING_FOR_CREATION."' AND m.object_id = o.object_id";

	$request = $main->{'db'}->{'DB_READ'}->prepare( $query ) or return -2;
	return undef if ( $request->execute() <= 0 );

	return( $request->fetchall_hashref('dbname') );
}


sub get_all_db_to_delete
{
	my( $main ) = @_;
	
	my $query = "SELECT m.dbname, m.object_id FROM  vhffs_mysql m, vhffs_object o WHERE o.state='".Vhffs::Constants::TO_DELETE."' AND m.object_id = o.object_id";

	$request = $main->{'db'}->{'DB_READ'}->prepare( $query ) or return -2;
	return undef if ( $request->execute() <= 0 );

	return( $request->fetchall_hashref('dbname') );
}



sub delete_db
{
	my $main = shift;
	my $db = shift;

	my $query;
		
	if( $db->fetch > 0 )
	{
		$db->add_history( "Ok, robots takes the destruction of this database" );
		my $dbi = mysql_admin_db_connect( $main );
		if( $dbi != 1 )
		{
#			$query = "REVOKE ALL PRIVILEGES ON `".$db->get_dbname."` . * FROM \"".$db->get_dbname."\"";

			$query = "DELETE FROM `user` WHERE User = '".$db->get_dbname."'";
			$dbi->do( $query ) or $db->add_history("Error while grant access to the database");

			$query = "DELETE FROM `db` WHERE User = '".$db->get_dbname."'";
			$dbi->do( $query ) or $db->add_history("Error while grant access to the database");

			$query = "DELETE FROM `tables_priv` WHERE User = '".$db->get_dbname."'";
			$dbi->do( $query ) or $db->add_history("Error while grant access to the database");

			$query = "DELETE FROM `columns_priv` WHERE User = '".$db->get_dbname."'";
			$dbi->do( $query ) or $db->add_history("Error while grant access to the database");

			$query = "DROP DATABASE `".$db->get_dbname."`";
			$dbi->do( $query ) or $db->add_history("Error while creating the database");

			$dbi->do( "FLUSH PRIVILEGES" );
			$dbi->disconnect;
		}
		$db->add_history( "Robots finished the destruction" );
		$db->delete;
	}
}



sub fix_password
{
	my ( $main , $dbname ) = @_;

	my $db = new Vhffs::Services::Mysql( $main , $dbname );
	my $query;
	
	if( $db->fetch > 0 )
	{
		my $dbi = mysql_admin_db_connect( $main );
		if( $dbi != 1 )
		{
			$query = "UPDATE user SET PASSWORD=PASSWORD('".$db->get_dbpassword."') WHERE user='".$db->get_dbusername."'";
			$dbi->do( $query ) or $db->add_history("Error while creating the database");
			$dbi->do( "FLUSH PRIVILEGES" );
			$dbi->disconnect;
		}
	}
}


sub create_db
{       
		my $main = shift;
		my $db = shift;

        my $query;
                
        if( ( defined $db ) && ( $db->fetch > 0 ) )
        {
                $db->add_history( "Ok, robots takes the creation of this database" );
                my $dbi = mysql_admin_db_connect( $main );
                if( $dbi != 1 )
                {
                        # create the database
                        $query = "CREATE DATABASE `".$db->get_dbname."`";
                        $dbi->do( $query ) or $db->add_history("Error while creating the database");

                        # grant privileges to user
#                       $query = "GRANT ALL PRIVILEGES ON `".$db->get_dbname."`.* TO `".$db->get_dbname."`@% IDENTIFIED BY '".$db->get_dbpassword."'";
                        $query = "GRANT ALL ON ".$db->get_dbname.".* TO `".$db->get_dbname."` IDENTIFIED BY '".$db->get_dbpassword."'";
                        $dbi->do( $query ) or $db->add_history( gettext("An error occured while granting privileges to an admin user") );

                        $dbi->do( "FLUSH PRIVILEGES" );
                        $dbi->disconnect;
                }
                $db->add_history( "Robots finished the creation" );
                $db->set_status( Vhffs::Constants::ACTIVATED );
                $db->commit;
				$db->blank_password;
        }
}



sub mysql_admin_db_connect
{
	use DBI;
	my $vhffs = shift;
	my $dbuser = $vhffs->get_config->get_mysql_admin_username;
	my $dbpass = $vhffs->get_config->get_mysql_admin_pass;
	my $dbhost = $vhffs->get_config->get_mysql_admin_host;

	$dbi = DBI->connect( "DBI:mysql:dbname=mysql;host=$dbhost",$dbuser,$dbpass ) or return -1;
	
	return $dbi;
}

sub update_db
{
		my $main = shift;
		my $db = shift;

        my $query;

        if( $db->fetch > 0 )
        {
                $db->add_history( "Ok, will change password for this database" );
                my $dbi = mysql_admin_db_connect( $main );
                if( $dbi != 1 )
                {
                        $query = "UPDATE user SET PASSWORD=PASSWORD('".$db->get_dbpassword."') WHERE User = '".$db->get_dbname."'";
                        $dbi->do( $query ) or $db->add_history("Error while grant access to the database");

                        $dbi->do( "FLUSH PRIVILEGES" );
                        $dbi->disconnect;
                }
                $db->add_history( "Robots changed the password for this database" );
                $db->set_status( Vhffs::Constants::ACTIVATED );
                $db->commit;
		$db->blank_password;
        }
}

sub get_all_db_to_update
{
        my( $main ) = @_;

        my $query = "SELECT m.dbname, m.object_id FROM  vhffs_mysql m, vhffs_object o WHERE o.state='".Vhffs::Constants::WAITING_FOR_MODIFICATION."' AND m.object_id = o.object_id";

        $request = $main->{'db'}->{'DB_READ'}->prepare( $query ) or return -2;
        return undef if ( $request->execute() <= 0 );

        return( $request->fetchall_hashref('dbname') );
}




1;
