#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.



# This file is a part of VHFFS4 Hosting Platform
# Please respect the licence of this file and the whole software

# Author: soda < dieu at gunnm dot org>

package Vhffs::Services::LargeFile;

use base qw(Vhffs::Object);
use Vhffs::Group;
use Vhffs::Functions;
use strict;
use DBI;



#Create a new LargeFile object
#needs to get filename, and user/group related-object
sub new
{
    my $main;
    my $filename;
    my $this;
    my $self;
    my $class;
    my $user;
    my $group;
    
    $class = shift;
    $main = shift;
    $filename = shift;
    $user = shift;
    $group = shift;
    
    $this = {};
    
    $this = $class->SUPER::new( $main , 1 , '401' );
    
    #We return an undefined value if the user or the SVNROOT are not correct
    return undef if( ! defined ( $filename ) );
    return undef if( length( $filename ) < 3 );
    return undef if( ! ( $filename =~ /^[\w\d\-\_\.]+$/ ) );
    return undef if( ( ! defined $group ) || ( $group->fetch < 1 ) );
    

    $this->{'user'} = $user;
    $this->{'group'} = $group;
    $this->{'filename'} = $filename;
    
    bless( $this , $class );
    
    return $this;
}


#Delete largefile entry in database
#Returns negative value if error happen
#Returns positive value if success
sub delete
{
    my $self = shift;
    my $query;
    my $request;

	return -1 if( $self->fetch < 0 );

    $query = "DELETE FROM vhffs_largefile WHERE object_id='".$self->{'object_id'}."'";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare($query);
    $request->execute or return -1;

    return -1 if( $self->SUPER::delete < 0 );
	return 1;
}



#Create a largefile entry on the database
#Needs :
#			- a valid largefile object
#			- a valid size
#			- a valid type
sub create
{
    my $self = shift;
	my $oid;
	my $request;
	my $handle;
   
	#Ok, see if user and group are valid on the database
	return -2 if ( $self->{'user'}->fetch < 0 );
    return -3 if ( $self->{'group'}->fetch < 0 );


    $self->{'owner_uid'} = $self->{'user'}->get_uid;
   

   	#Create the main VHFFS object in the database
	#The new Largefile object will inherit this object
    $oid = $self->SUPER::create();
    if ( $oid lt 0 )
    {
		return( -1 );
    }
    else
    {
		$self->{'object_id'} = $oid;
    }
   
    #Finally, create the object
    $request = "INSERT INTO vhffs_largefile (filename,size,type,creating_date,owner_uid,owner_gid,object_id)
				 VALUES( ? , ? , ? , NOW() , ? , ? , ? )";
    $handle = $self->{'db'}->{'DB_WRITE'}->prepare( $request );
    $handle->execute( $self->{'filename'} , $self->{'size'} , $self->{'type'} , $self->{'user'}->get_uid , $self->{'group'}->get_gid , $self->{'object_id'} ) or return( -2 );

    return 1;
}


#Get object informations from database.
#The group MUST be valid to work
#Return positive value if success
#Negative value if fails
sub fetch
{
    my $self = shift;
   	my ( $query , $handle , $rows , $result , $request); 

	$query = "SELECT * FROM vhffs_largefile WHERE filename ='".$self->{'filename'}."' AND owner_gid='".$self->{'group'}->get_gid."'";
	$handle = $self->{'db'}->{'DB_READ'}->prepare( $query )  or return -1;

	$rows = $handle->execute() or return -3;

	return -2 if( $rows <= 0 );
    $result = $handle->fetchrow_hashref();
    
    foreach ( keys %{$result} )
    {
		$self->{$_} = $result->{$_}
    }
    
    
    $self->{'group'} = new Vhffs::Group( $self->{'main'} , undef ,  $self->{'owner_uid'} , $self->{'owner_gid'} );
    return -1 if( $self->{'group'}->fetch < 0 );
    
    $self->{'user'} = new  Vhffs::User( $self->{'main'} , undef , $self->{'owner_uid'} );
    return -1 if( $self->{'user'}->fetch < 0 );
    
    return -4 if( $self->SUPER::fetch < 0 );
    
    return 1;
}


#When invoking commit METHOD, MUST USE before fetch() method on object
#Returns 	- negative value if fails (-2 if the error belongs to parent object)
#			- positive value if surccess
sub commit
{
	my $self = shift;	
	my ( $query , $handle );

	$self->{'licence'} = "unknown licence" if( ! defined $self->{'licence'} );
	$self->{'password'} = "" if( ! defined $self->{'password'} );
	$self->{'hash'} = "" if( ! defined $self->{'hash'} );
	$self->{'size'} = "unknown type" if( ! defined $self->{'type'} );
	$self->{'username'} = "" if( ! defined $self->{'username'} );
	$self->{'end_date'} = "NULL" if( ! defined $self->{'end_date'} );

	$query = "UPDATE vhffs_largefile SET 
										size = ? ,
										licence = ? ,
										username = ? ,
										password = ? ,
										hash = ?
										WHERE file_id= ? ";
	
	$handle = $self->{'db'}->{'DB_WRITE'}->prepare($query);
	$handle->execute( $self->{'size'} , $self->{'licence'} , $self->{'username'} , $self->{'password'} , $self->{'hash'} , $self->{'file_id'} )  or return -1;

	return -2 if( $self->SUPER::commit < 0 );

	return 1;
}

sub get_title
{
	my $self = shift;
	return( $self->{'filename'} );
}

sub get_filename
{
	my $self = shift;
	return( $self->{'filename'} );
}

sub set_licence
{
	my $self = shift;
	my $licence = shift;
	$self->{'licence'} = quotemeta( $licence );

	return 1;
}

sub get_licence
{
	my $self	=	shift;
	
	return( Vhffs::Functions::stripslashes( $self->{'licence'} ) );
}

sub set_size
{
	my $self = shift;
	my $size = shift;

	return -1 if( ! defined ( $size =~ /^[\d]+$/ ) );
	
	$self->{'size'} = $size;

	return 1;
}

sub get_size
{
	my $self = shift;
	return( $self->{'size'} );
}

sub set_type
{
	my $self = shift;
	my $type = shift;

	return -1 if( ! defined ( $type =~ /^[a-zA-Z0-9\.]*$]/ ) );

	$self->{'type'} = $type;
	return 1;
}

sub get_type
{
	my $self = shift;
	return( $self->{'type'} );
}

sub get_creating_date
{
	my $self = shift;
	return( $self->{'creating_date'} );
}

sub get_end_date
{
	my $self = shift;
	return $self->{'end_date'};
}

sub set_end_date
{
	my $self = shift;
	#####FIXME
	return 1;
}

sub get_username
{
	my $self = shift;
	return( $self->{'username'} );
}

sub set_username
{
	my $self = shift;
	my $username = shift;

	return -1 if( ! ( $username =~ /^[a-zA-Z0-9\-]+$/ ) );

	$self->{'username'} = $username;
	return 1;
}

sub get_password
{
	my $self = shift;
	return( $self->{'password'} );
}

sub set_password
{
	use Vhffs::Functions;
	my $self = shift;
	my $password = shift;

	$self->{'password'} = Vhffs::Functions::password_encrypt( $password );
	return 1;
}

sub set_hash
{
	my $self = shift;
	my $hash = shift;

	return 1 if( ! defined $hash );
	return -2 if( ! defined ( $hash =~ /[a-zA-Z0-9\d\s\-]*/ ) );

	$self->{'hash'} = $hash;
	return 1;
}

sub get_hash
{
	my $self = shift;
	return( $self->{'hash'} );
}


sub get_owneruid
{
	my( $self ) = @_;
	return $self->{'owner_uid'};
}

sub get_ownergid
{
	my $self = shift;
	return $self->{'owner_gid'};
}

sub getall
{
    my $vhffs	=	shift;
    my $state	=	shift;
    my $name	=	shift;
    my $group	=	shift;

    my $query;
    my $request;

    my $objs;
    my $result;
    my $tmp;
	
	
	$query = "SELECT * FROM  vhffs_largefile lf, vhffs_object o WHERE lf.object_id = o.object_id ";
	$query.= " AND o.state='".$state."'" if( defined $state);
	$query.= " AND lf.owner_gid='".$group->get_gid."'" if( defined $group);
	$query.= " AND lf.filename LIKE '%".$name."%'" if( defined $name);
    $query .= " ORDER BY lf.filename";

    $request = $vhffs->{'db'}->{'DB_READ'}->prepare( $query );
    
    my $rows = $request->execute;
    
    return undef if( $rows == 0);

    while( $result = $request->fetchrow_hashref )
    {
		$group = new Vhffs::Group( $vhffs , undef , $result->{'owner_uid'} , $result->{'owner_gid'} );

        $tmp = new Vhffs::Services::LargeFile( $vhffs , $result->{'filename'} , undef , $group );
        if( ( defined ( $tmp ) ) && ( $tmp->fetch > 0 ) )
        {
            push @{$objs} , $tmp;
        }
    }
    return $objs;
}



sub getall_by_group
{
    my $vhffs = shift;
    my $group = shift;

    my $query;
    my $request;

    my $objs;
    my $result;
    my $tmp;

    return undef if( $group->fetch < 1 );
     
    $query = "SELECT lf.filename, lf.object_id FROM  vhffs_largefile lf, vhffs_object o WHERE lf.object_id = o.object_id AND lf.owner_gid='".$group->get_gid."'";
    
    $request = $vhffs->{'db'}->{'DB_READ'}->prepare( $query );
    my $rows = $request->execute;

    return undef if( $rows == 0);

    $result = $request->fetchall_hashref( 'filename' );

    foreach( keys %{$result} )
    {
        $tmp = new Vhffs::Services::LargeFile( $vhffs , $_  , undef , $group);
        if( ( defined ( $tmp ) ) && ( $tmp->fetch > 0 ) )
        {
            push @{$objs} , $tmp;
        }
    }
    return $objs;
}




sub set_user
{
	my ( $self , $user ) = @_;
	$self->{'user'} = $user;
}

sub set_group
{
	my ( $self , $group ) = @_;
	$self->{'group'} = $group;
}


1;

__END__

=head1 NAME
Vhffs::LargeFile - Manage hosted files in VHFFS

=head1 SYNOPSIS

	use Vhffs::Main;
	use Vhffs::User;
	use Vhffs::Group;
	use Vhffs::LargeFile;

	$vhffs = init Vhffs::Main;
	my $user = new Vhffs::User( $vhffs , 'myuser' , '401' );
	my $group = new Vhffs::Group( $vhffs , 'mygroup' , '401' );
	my $file = new Vhffs::LargeFile( $vhffs , 'filename' , $user , $group );

	if( $file->fetch < 0 )
	{
		print "This file does not exist for this group or error in parameters";
		exit 1;
	}
	if( $file->create > 0 )
	{
		print "File is now created";
	}

=head1 DESCRIPTION

Manage hosted files in VHFFS platform. Methods returns negative
values if error or positive value (most of case 1).
The object contains at least type and filename. After, you can add
licence or size informations. 

The username and password properties are present only if the 
administrator want use an FTP server for each files. For example, for
uploading each files, the user need an FTP access and the account is present
in each files description.

=head1 METHODS

new( Vhffs::Main , "filename" , Vhffs::User , Vhffs::Group )

delete()

create()

fetch()

commit()

get_title()

get_filename()

get_licence()

set_licence( "mylicence" )

set_size( "100" )

get_size()

set_type( "mytype" )

get_type( )

get_creating_date()

get_end_date()

set_end_date( "date" )

get_username()

set_username( "myusername" )

get_password()

set_password( "mypassword" )

set_hash()

get_hash()

get_owneruid()

get_ownergid()

getall( Vhffs::Main , $state( in Vhffs::Constants) , "filename" , Vhffs::Group )

getall_by_group( Vhffs::Main , Vhffs::Group )

set_user( Vhffs::User )

set_group( Vhffs::Group )

=head1 SEE ALSO

Vhffs::Main, Vhffs::Conf

=head1 AUTHOR

	Julien Delange < dieu at gunnm dot org>

=head1 COPYRIGHT
	(c) Julien Delange

