#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;


use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Services::Httpd;
use Vhffs::Acl;
use Vhffs::Constants;
use Vhffs::Note;

my $panel = new Vhffs::Panel::Main();
my $temp;
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $group = $panel->{'group'};
my $projectname = $session->param("project");
my $cgi = $panel->{'cgi'};
my $servername = $cgi->param("name");
my $template;

my $templatesdir = $vhffs->get_config->get_templatedir;


#Use is not allowed to see this page, only MODERATOR and ADMIN
if( ($user->is_moderator != 1 ) && ( $user->is_admin ) != 1 ) 
{
	$template = new HTML::Template( filename => "$templatesdir/misc/simplemsg.tmpl" );
	my $message = gettext("You're not allowed to do this (ACL rights)");
	$template->param( MESSAGE => $message );
}
else
{
	my $output = "";
	$template = new HTML::Template( filename => "$templatesdir/admin/misc/moderation.tmpl" );

	$template->param( TITLE => gettext("Moderation") );

	#Treat Groups to moderate
	use Vhffs::Panel::Group;
	$template->param( TEXT_GROUP => gettext("Groups awaiting validation") );
	my $groups = Vhffs::Group::getall( $vhffs , Vhffs::Constants::WAITING_FOR_VALIDATION );
	
	$output = "";
	
	if( defined $groups )
	{
		foreach $temp ( @{$groups} )
		{
			my $subtemplate = new HTML::Template( filename => "$templatesdir/admin/misc/moderation_part.tmpl" );
			$subtemplate->param( NAME	=> $temp->get_groupname );
	
            if( $vhffs->get_config->use_notation == 1 )
            {
                $subtemplate->param( OWNER  => $temp->get_user->get_username);
				$subtemplate->param( NOTE   => Vhffs::Note::get_note( $vhffs , $temp->get_user ) );
                $subtemplate->param( OID_ASKER  => $temp->get_user->get_oid);
            }
            else
            {
                 $subtemplate->param( OWNER  => $temp->get_user->get_username );
            }
		
			
			$subtemplate->param( GROUP	=> $temp->get_groupname );
			$subtemplate->param( OID	=> $temp->get_oid );
			$subtemplate->param( DESCRIPTION	=> Vhffs::Functions::stripslashes( $temp->get_description ) );
			$subtemplate->param( ACCEPT	=> gettext("Accept") );
			$subtemplate->param( REFUSE	=> gettext("Refuse") );
			$output.= $subtemplate->output;
		}

		$template->param( MODERATION_GROUPS => $output );
	}
	else
	{
		$template->param( MODERATION_GROUPS => gettext("No Group to validate") );
	}

	if( $vhffs->get_config->use_web == 1 )
	{
		#Treat Website to moderate
		use Vhffs::Services::Httpd;
		$template->param( TEXT_WEB => gettext("Web Area awaiting validation") );
		my $webs = Vhffs::Services::Httpd::getall( $vhffs , Vhffs::Constants::WAITING_FOR_VALIDATION);
		my $web;
		$output = "";
	
		if( defined $webs )
		{
			foreach $temp ( @{$webs} )
			{
				my $subtemplate = new HTML::Template( filename => "$templatesdir/admin/misc/moderation_part.tmpl" );
				$subtemplate->param( NAME	=> $temp->get_servername );

				if( $vhffs->get_config->use_notation == 1 )
				{
                $subtemplate->param( OWNER  => $temp->get_user->get_username);
				$subtemplate->param( NOTE   => Vhffs::Note::get_note( $vhffs , $temp->get_user ) );
					$subtemplate->param( OID_ASKER	=> $temp->get_user->get_oid);
				}
				else
				{
					$subtemplate->param( OWNER	=> $temp->get_user->get_username );
				}

				$subtemplate->param( GROUP	=> $temp->get_group->get_groupname );
				$subtemplate->param( OID	=> $temp->get_oid );
				$subtemplate->param( DESCRIPTION	=> $temp->get_description );
				$subtemplate->param( ACCEPT	=> gettext("Accept") );
				$subtemplate->param( REFUSE	=> gettext("Refuse") );
				$output.= $subtemplate->output;
			}
	
			$template->param( MODERATION_WEB => $output );
		}
		else
		{
			$template->param( MODERATION_WEB => gettext("No Web Area to validate") );
		}
	}


	if( $vhffs->get_config->use_dns == 1 )
	{
		#Treat Mail domains to moderate
		use Vhffs::Services::DNS;
		$template->param( TEXT_DNS => gettext("DNS awaiting validation") );
		my $nss = Vhffs::Services::DNS::getall( $vhffs , Vhffs::Constants::WAITING_FOR_VALIDATION );
		$output = "";
	
		if( defined $nss )
		{
			foreach $temp ( @{$nss} )
			{
				my $subtemplate = new HTML::Template( filename => "$templatesdir/admin/misc/moderation_part.tmpl" );
            if( $vhffs->get_config->use_notation == 1 )
            {
                $subtemplate->param( OWNER  => $temp->get_user->get_username);
				$subtemplate->param( NOTE   => Vhffs::Note::get_note( $vhffs , $temp->get_user ) );
                $subtemplate->param( OID_ASKER  => $temp->get_user->get_oid);
            }
            else
            {
                 $subtemplate->param( OWNER  => $temp->get_user->get_username );
            }
				$subtemplate->param( NAME				=> $temp->get_domain );
				$subtemplate->param( GROUP				=> $temp->get_group->get_groupname );
				$subtemplate->param( OID				=> $temp->get_oid );
				$subtemplate->param( DESCRIPTION		=> $temp->get_description );
				$subtemplate->param( ACCEPT				=> gettext("Accept") );
				$subtemplate->param( REFUSE				=> gettext("Refuse") );
				$output.= $subtemplate->output;
			}
	
			$template->param( MODERATION_DNS => $output );
		}
		else
		{
			$template->param( MODERATION_DNS => gettext("No DNS to validate") );
		}
	}



	if( $vhffs->get_config->use_cvs == 1 )
	{
		#Treat Mail domains to moderate
		use Vhffs::Services::Cvs;
		$template->param( TEXT_CVS => gettext("CVS repository awaiting validation") );
		my $repos = Vhffs::Services::Cvs::getall( $vhffs , Vhffs::Constants::WAITING_FOR_VALIDATION );
		$output = "";
	
		if( defined $repos )
		{
			foreach $temp ( @{$repos} )
			{

				my $subtemplate = new HTML::Template( filename => "$templatesdir/admin/misc/moderation_part.tmpl" );

    	        if( $vhffs->get_config->use_notation == 1 )
	            {
                	$subtemplate->param( OWNER  => $temp->get_user->get_username);
					$subtemplate->param( NOTE   => Vhffs::Note::get_note( $vhffs , $temp->get_user ) );
           		    $subtemplate->param( OID_ASKER  => $temp->get_user->get_oid);
            	}
            	else
            	{
                 	$subtemplate->param( OWNER  => $temp->get_user->get_username );
            	}
				$subtemplate->param( NAME	=> $temp->get_cvsroot );
				$subtemplate->param( GROUP	=> $temp->get_group->get_groupname );
				$subtemplate->param( OID	=> $temp->get_oid );
				$subtemplate->param( DESCRIPTION	=> $temp->get_description );
				$subtemplate->param( ACCEPT	=> gettext("Accept") );
				$subtemplate->param( REFUSE	=> gettext("Refuse") );
				$output.= $subtemplate->output;
			}
	
			$template->param( MODERATION_CVS => $output );
		}
		else
		{
			$template->param( MODERATION_CVS => gettext("No repository to validate") );
		}
	}



	if( $vhffs->get_config->use_mailing == 1 )
	{
		#Treat Mail domains to moderate
		use Vhffs::Panel::Mailinglist;
		$template->param( TEXT_MAILING => gettext("List awaiting validation") );
		my $mls = Vhffs::Services::Mailing::getall( $vhffs , Vhffs::Constants::WAITING_FOR_VALIDATION );
		$output = "";
	
		if( defined $mls )
		{
			foreach $temp ( @{$mls} )
			{
				my $subtemplate = new HTML::Template( filename => "$templatesdir/admin/misc/moderation_part.tmpl" );
				$subtemplate->param( NAME	=> $temp->get_localpart ."\@". $temp->get_domain );
		        
				if( $vhffs->get_config->use_notation == 1 )
                {
                	$subtemplate->param( OWNER  => $temp->get_user->get_username);
					$subtemplate->param( NOTE   => Vhffs::Note::get_note( $vhffs , $temp->get_user ) );
                    $subtemplate->param( OID_ASKER  => $temp->get_user->get_oid);
                }
                else
                {
                    $subtemplate->param( OWNER  => $temp->get_user->get_username );
                }	
				$subtemplate->param( GROUP	=> $temp->get_group->get_groupname );
				$subtemplate->param( OID	=> $temp->get_oid );
				$subtemplate->param( DESCRIPTION	=> $temp->get_description );
				$subtemplate->param( ACCEPT	=> gettext("Accept") );
				$subtemplate->param( REFUSE	=> gettext("Refuse") );
				$output.= $subtemplate->output;
			}
	
			$template->param( MODERATION_MAILING => $output );
		}
		else
		{
			$template->param( MODERATION_MAILING => gettext("No list to validate") );
		}
	}



	if( $vhffs->get_config->use_svn == 1 )
	{
		#Treat Mail domains to moderate
		use Vhffs::Services::Svn;
		use Vhffs::Constants;
		$template->param( TEXT_SVN => gettext("Subversion repository awaiting validation") );
		my $repos = Vhffs::Services::Svn::getall( $vhffs , Vhffs::Constants::WAITING_FOR_VALIDATION );
		$output = "";
		my $svn;
		if( defined $repos )
		{
			foreach $svn ( @{$repos} )
			{
				my $subtemplate = new HTML::Template( filename => "$templatesdir/admin/misc/moderation_part.tmpl" );
				$subtemplate->param( NAME	=> $svn->get_reponame);
				
                if( $vhffs->get_config->use_notation == 1 )
                {
                	$subtemplate->param( OWNER  => $svn->get_user->get_username);
					$subtemplate->param( NOTE   => Vhffs::Note::get_note( $vhffs , $svn->get_user ) );
                    $subtemplate->param( OID_ASKER  => $svn->get_user->get_oid);
                }
                else
                {
                    $subtemplate->param( OWNER  => $svn->get_user->get_username );
                }

				$subtemplate->param( GROUP	=> $svn->get_group->get_groupname );
				$subtemplate->param( OID	=> $svn->get_oid );
				$subtemplate->param( DESCRIPTION	=> $svn->get_description );
				$subtemplate->param( ACCEPT	=> gettext("Accept") );
				$subtemplate->param( REFUSE	=> gettext("Refuse") );
				$output.= $subtemplate->output;
			}
	
			$template->param( MODERATION_SVN => $output );
		}
		else
		{
			$template->param( MODERATION_SVN => gettext("No repository to validate") );
		}
	}




	if( $vhffs->get_config->use_mail == 1 )
	{
		#Treat Mail domains to moderate
		use Vhffs::Panel::Mail;
		$template->param( TEXT_MAIL => gettext("Mail Area awaiting validation") );
		my $mails = Vhffs::Services::Mail::getall( $vhffs , Vhffs::Constants::WAITING_FOR_VALIDATION );
		$output = "";
	
		if( defined $mails )
		{
			foreach $temp ( @{$mails} )
			{
				my $subtemplate = new HTML::Template( filename => "$templatesdir/admin/misc/moderation_part.tmpl" );
				$subtemplate->param( NAME	=> $temp->get_domain );

                if( $vhffs->get_config->use_notation == 1 )
                {
                	$subtemplate->param( OWNER  => $temp->get_user->get_username);
					$subtemplate->param( NOTE   => Vhffs::Note::get_note( $vhffs , $temp->get_user ) );
                    $subtemplate->param( OID_ASKER  => $temp->get_user->get_oid);
                }
                else
                {
                    $subtemplate->param( OWNER  => $temp->get_user->get_username );
                }

				$subtemplate->param( GROUP	=> $temp->get_group->get_groupname );
				$subtemplate->param( OID	=> $temp->get_oid );
				$subtemplate->param( DESCRIPTION	=> $temp->get_description);
				$subtemplate->param( ACCEPT	=> gettext("Accept") );
				$subtemplate->param( REFUSE	=> gettext("Refuse") );
				$output.= $subtemplate->output;
			}
	
			$template->param( MODERATION_MAIL => $output );
		}
		else
		{
			$template->param( MODERATION_MAIL => gettext("No Mail Area to validate") );
		}
	}



	if( $vhffs->get_config->use_mysql == 1 )
	{
		use Vhffs::Services::Mysql;
		$template->param( TEXT_MYSQL => gettext("MySQL database awaiting validation") );
		my $dbs = Vhffs::Services::Mysql::getall( $vhffs , Vhffs::Constants::WAITING_FOR_VALIDATION );
		$output = "";
	
		if( defined $dbs )
		{
			foreach $temp ( @{$dbs} )
			{
				my $subtemplate = new HTML::Template( filename => "$templatesdir/admin/misc/moderation_part.tmpl" );

                if( $vhffs->get_config->use_notation == 1 )
                {
                	$subtemplate->param( OWNER  => $temp->get_user->get_username);
					$subtemplate->param( NOTE   => Vhffs::Note::get_note( $vhffs , $temp->get_user ) );
                    $subtemplate->param( OID_ASKER  => $temp->get_user->get_oid);
                }
                else
                {
                    $subtemplate->param( OWNER  => $temp->get_user->get_username );
                }
				
				$subtemplate->param( NAME	=> $temp->get_dbname );
				$subtemplate->param( GROUP	=> $temp->get_group->get_groupname );
				$subtemplate->param( OID	=> $temp->get_oid );
				$subtemplate->param( DESCRIPTION	=> $temp->get_description );
				$subtemplate->param( ACCEPT	=> gettext("Accept") );
				$subtemplate->param( REFUSE	=> gettext("Refuse") );
				$output.= $subtemplate->output;
			}
	
			$template->param( MODERATION_MYSQL => $output );
		}
		else
		{
			$template->param( MODERATION_MYSQL => gettext("No database to validate") );
		}
	}

	if( $vhffs->get_config->use_postgres == 1 )
	{
		#Treat Mail domains to moderate
		use Vhffs::Services::Postgres;
		$template->param( TEXT_POSTGRES => gettext("Postgres database awaiting validation") );
		my $dbs = Vhffs::Services::Postgres::getall( $vhffs , Vhffs::Constants::WAITING_FOR_VALIDATION );
		$output = "";
	
		if( defined @{$dbs} )
		{
			foreach $temp ( @{$dbs} )
			{
				my $subtemplate = new HTML::Template( filename => "$templatesdir/admin/misc/moderation_part.tmpl" );

                if( $vhffs->get_config->use_notation == 1 )
                {
                	$subtemplate->param( OWNER  => $temp->get_user->get_username);
					$subtemplate->param( NOTE   => Vhffs::Note::get_note( $vhffs , $temp->get_user ) );
                    $subtemplate->param( OID_ASKER  => $temp->get_user->get_oid);
                }
                else
                {
                    $subtemplate->param( OWNER  => $temp->get_user->get_username );
                }

				$subtemplate->param( NAME	=> $temp->get_dbname );
				$subtemplate->param( GROUP	=> $temp->get_group->get_groupname );
				$subtemplate->param( OID	=> $temp->get_oid );
				$subtemplate->param( DESCRIPTION	=> $temp->get_description );
				$subtemplate->param( ACCEPT	=> gettext("Accept") );
				$subtemplate->param( REFUSE	=> gettext("Refuse") );
				$output.= $subtemplate->output;
			}
	
			$template->param( MODERATION_POSTGRES => $output );
		}
		else
		{
			$template->param( MODERATION_POSTGRES => gettext("No database to validate") );
		}
	}

	if( $vhffs->get_config->use_largefile == 1 )
	{
		use Vhffs::Services::LargeFile;
		$template->param( TEXT_LARGEFILE => gettext( "Files awaiting validation" ) );
		my $files = Vhffs::Services::LargeFile::getall( $vhffs , Vhffs::Constants::WAITING_FOR_VALIDATION );
		$output = "";

		if( defined @{$files} )
		{
			foreach $temp ( @{$files} )
			{
				my $subtemplate = new HTML::Template( filename => "$templatesdir/admin/misc/moderation_part.tmpl" );

                if( $vhffs->get_config->use_notation == 1 )
                {
                	$subtemplate->param( OWNER  => $temp->get_user->get_username);
					$subtemplate->param( NOTE   => Vhffs::Note::get_note( $vhffs , $temp->get_user ) );
                    $subtemplate->param( OID_ASKER  => $temp->get_user->get_oid);
                }
                else
                {
                    $subtemplate->param( OWNER  => $temp->get_user->get_username );
                }

				$subtemplate->param( NAME	=> $temp->get_filename ."( ".$temp->get_size."Mo,".$temp->get_type." )" );
				$subtemplate->param( GROUP	=> $temp->get_group->get_groupname );
				$subtemplate->param( OID	=> $temp->get_oid );
				$subtemplate->param( DESCRIPTION	=> $temp->get_description );
				$subtemplate->param( ACCEPT	=> gettext("Accept") );
				$subtemplate->param( REFUSE	=> gettext("Refuse") );
				$output.= $subtemplate->output;
			}
	
			$template->param( MODERATION_LARGEFILE => $output );
		}
		else
		{
			$template->param( MODERATION_LARGEFILE => gettext("No files to validate") );
		}
	}


	if( $vhffs->get_config->use_repository == 1 )
	{
		use Vhffs::Services::Repository;
		$template->param( TEXT_REPOSITORY => gettext( "Download repository awaiting validation" ) );
		my $repos = Vhffs::Services::Repository::getall( $vhffs , Vhffs::Constants::WAITING_FOR_VALIDATION );
		$output = "";

		if( defined @{$repos} )
		{
			foreach $temp ( @{$repos} )
			{
				my $subtemplate = new HTML::Template( filename => "$templatesdir/admin/misc/moderation_part.tmpl" );

		                if( $vhffs->get_config->use_notation == 1 )
		                {
		                	$subtemplate->param( OWNER  => $temp->get_user->get_username);
					$subtemplate->param( NOTE   => Vhffs::Note::get_note( $vhffs , $temp->get_user ) );
					$subtemplate->param( OID_ASKER  => $temp->get_user->get_oid);
		                }
		                else
		                {
		                    $subtemplate->param( OWNER  => $temp->get_user->get_username );
		                }

				$subtemplate->param( NAME	=> $temp->get_name );
				$subtemplate->param( GROUP	=> $temp->get_group->get_groupname );
				$subtemplate->param( OID	=> $temp->get_oid );
				$subtemplate->param( DESCRIPTION	=> $temp->get_description );
				$subtemplate->param( ACCEPT	=> gettext("Accept") );
				$subtemplate->param( REFUSE	=> gettext("Refuse") );
				$output.= $subtemplate->output;
			}
	
			$template->param( MODERATION_REPOSITORY => $output );
		}
		else
		{
			$template->param( MODERATION_REPOSITORY => gettext("No repository to validate") );
		}
	}

	
}

display Vhffs::Panel::Main($panel, $template->output);
