#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


require 5.004;
use POSIX;
use strict;
use locale;
use Locale::gettext;
use HTML::Template;
use CGI;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Constants;

my $vhffs = init Vhffs::Main;

#Set the language cookie
my $cookie = Vhffs::Panel::Main::cookie_lang( $vhffs );

my $templatedir = $vhffs->get_config->get_templatedir;
my $hostname = $vhffs->get_config->get_host_name;
my $cgi = new CGI;
my $template;

Vhffs::Panel::Main::check( $vhffs );

$template = new HTML::Template( filename => $templatedir."/main/auth.tmpl", associate => $cgi );

$template->param( TITLE => gettext("VHFFS Login") );
$template->param( TEXT_WELCOME => sprintf( gettext("Welcome on %s") , $hostname )   );
$template->param( VHFFS_INFO => sprintf( "Run VHFFS %s (%s)" , Vhffs::Constants::VHFFS_VERSION , Vhffs::Constants::VHFFS_RELEASE_NAME ) );
$template->param( TEXT_PLEASEIDENTIFY => gettext("Please enter your username and password") );
$template->param( TEXT_USERNAME => gettext("Username") );
$template->param( TEXT_PASSWORD => gettext("Password") );
$template->param( TEXT_LOGIN => gettext("Access to panel") );
$template->param( TEXT_LOSTPASSWORD => gettext("I've lost my password") );
$template->param( TEXT_SUBSCRIBE => gettext("Subscribe") );

$template->param( LANGS => Vhffs::Panel::Main::select_lang( $vhffs ) );


if( $vhffs->get_config->stats_on_home == 1 )
{
    use Vhffs::Stats;
    my $stats = new Vhffs::Stats( $vhffs );
    $stats->fetch;
    my $users  = $stats->get_user_total;
    my $groups = $stats->get_groups_total;

    $template->param( TEXT_STATS => sprintf( gettext( "Woah, %s users and %s groups already trust %s" ) , $users, $groups , $hostname ) );
}

if( $vhffs->get_config->get_panel_public == 1 )
{
    $template->param( TEXT_PUBLIC => gettext( "Go to public area" ) );
}

display_light Vhffs::Panel::Main( $vhffs , $template , $cookie );
