#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Panel::Group;

my $panel = new Vhffs::Panel::Main;
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $cgi = $panel->{'cgi'};
my $message;

my $groupname = $cgi->param("PROJECT_NAME");
my $description = $cgi->param("PROJECT_USAGE");
my $group,
my $retour;

my $templatedir = $vhffs->get_config->get_templatedir;

if( ( ! defined ( $groupname ))  ||  ( ! defined $description ) ) 
{
	$message = gettext("CGI Errror!");
}
elsif( ! ( $groupname =~ /^[a-z0-9]+$/ ) )
{
		$message = gettext("The groupname should contain at least 3 caracters and must contain only letters or numbers in lower case");
}
elsif( length( $groupname ) > 12 )
{
		$message = gettext("The groupname can have no more than 12 caracters.");
}
else
{
	$retour = Vhffs::Panel::Group::create_group( $groupname , $user , $vhffs );

	if( $retour == -1  )
	{
		$message = gettext("The groupname should contain at least 3 caracters and must contain only letters or numbers");
	}
	#elsif( ! defined ( $group = Vhffs::Panel::Group::create_group( $groupname , $user , $vhffs ) ) )
	elsif( $retour == -2 )
	{
		$message = gettext("This group already exists");
	}
	elsif( $retour < -2 )
	{
		$message = gettext("Error while creation !");
	}
	else
	{
		$group = new Vhffs::Group( $vhffs , $groupname , $user );
		$group->fetch;
		$group->set_description( quotemeta( $description ) );
	
		# Commit all the changes for the current project
		$group->commit;
		$message = gettext("Project Successfully created !");
	}
}
my $template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
$template->param( MESSAGE => $message );

set_refresh_url Vhffs::Panel::Main($panel, "/panel.pl", 0);
display Vhffs::Panel::Main($panel, $template->output);
