#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;


use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Functions;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Services::Mailing;
use Vhffs::Acl;
use Vhffs::Constants;
my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $group = $panel->{'group'};
my $projectname = $session->param("project");
my $cgi = $panel->{'cgi'};
my $domain = $cgi->param("DOMAIN");
my $lpart = $cgi->param("LOCALPART");
my $member = $cgi->param("MEMBER");
my $right = $cgi->param("RIGHT");

my $template;
my $subtemplate;
my $message;

my $templatedir = $vhffs->get_config->get_templatedir;

my $list = new Vhffs::Services::Mailing( $vhffs , $lpart , $domain , $user , $group );

$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );

if( ( ! defined $lpart ) ||( ! defined $domain )  )
{
	$message = gettext( "CGI Error!");
}
elsif( ! defined ( $list ) )
{
	$message = gettext( "Cannot build object");
}
elsif( $list->fetch < 0 )
{
	$message = gettext( "Cannot get informations on this object");
}
elsif( $list->get_status != Vhffs::Constants::ACTIVATED )
{
	$message = gettext( "This object is not functionnal yet. Please wait creation or moderation.");
}
elsif( ( Vhffs::Acl::what_perm_for_user( $user , $list , $vhffs ) < Vhffs::Constants::ACL_MODIFY ) && ( $user->is_admin != 1 ) )
{
	$message = gettext("You're not allowed to do this (ACL rights)");
}
elsif( Vhffs::Functions::valid_mail( $member ) < 0 )
{
	$message = gettext("Not valid mail");
}
elsif( ! ( $right =~ /^[0-9]+$/ ) )
{
	$message = gettext("CGI Error!");
}
else
{
	if( ( my $retour = $list->change_right_for_sub( $member , $right ) ) < 0 )
	{
		$message = gettext( "An error occured while modifying the rights" );
	}
	else
	{
		$message = gettext( "Rights successfully changed" );
	}

}

$template->param( MESSAGE => $message );
set_refresh_url Vhffs::Panel::Main($panel, "/mailinglist/prefs.pl?local=$lpart&domain=$domain", 0);
display Vhffs::Panel::Main($panel, $template->output);
