#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

#This is a part of VHFFS system
#This is a free software, no commercial use is allowed
#If you do a commercial use without author's authorisation
#We will steal your fridge and rape your dog

#This bots send mailings to all hosted people
#Convert mailing from utf8 to perl internal's

#TODO : Declare an encoding system in the vhffs.conf for mailings

use strict;
use Encode;
use utf8;
use Vhffs::Main;
use Vhffs::User;
use Vhffs::Functions;
use Vhffs::Robots::Mailing;
use Vhffs::Robots::User;
use Vhffs::Robots;
use Vhffs::Constants;


my $users;
my $user;
my $name;
my $idm;
my $vhffs = init Vhffs::Main;

Vhffs::Robots::lock( $vhffs );

my $mailings = Vhffs::Robots::Mailing::getall_mailings( $vhffs );
my $from;
my $message;
my $subject;
my $tmp;


$from = $vhffs->get_config->get_master_mail;

if( ! defined $from )
{
	Vhffs::Robots::vhffs_log( "Cannot send mailing, from (master mail) is not declared in config file" , $vhffs);
	Vhffs::Robots::unlock( $vhffs );
	exit( -1 );
}

if( defined $mailings )
{
	$users = Vhffs::User::getall( $vhffs , undef );

	#Exit if no users are present
	exit( 1 ) if( ! ( defined( $users ) ) );

	foreach $idm ( keys %{$mailings} )
	{
		next if( ! defined $mailings->{$idm}{message} );
		next if( ! defined $mailings->{$idm}{subject} );

		my $query = "UPDATE vhffs_mailings SET state='".Vhffs::Constants::ACTIVATED."' WHERE id_mailing='".$idm."'";
		my $request = $vhffs->get_db_object->{'DB_WRITE'}->prepare( $query );
		$request->execute or print ( "error" );

		$subject = Vhffs::Functions::stripslashes( $mailings->{$idm}{subject} );
		$message = Vhffs::Functions::stripslashes( $mailings->{$idm}{message} );


		foreach $user ( @{$users} )
		{
			next if( ! defined( $user ) );
			next if( $user->fetch < 0 );
	
			Vhffs::Functions::send_mail( $from , $user->get_mail , $subject , $message , $vhffs );
		}
	}
}

Vhffs::Robots::unlock( $vhffs );

exit( 0 );
